"use strict";

import React, { cloneElement, isValidElement } from 'react';
import { compact } from '@chakra-ui/utils';
import { omitThemingProps } from "../../style-system/index.js";
import { HStack } from "../stack/index.js";
import { forwardRef, useMultiStyleConfig } from "../system/index.js";
import { Avatar } from "./avatar.js";
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
/**
 * TODO: Possible improvments
 */
export const AvatarGroup = forwardRef((props, ref) => {
  const styles = useMultiStyleConfig('Avatar', props);
  const {
    children,
    max = null,
    borderRadius = 'full',
    borderColor = 'white',
    ...rest
  } = omitThemingProps(props);
  /**
   * Only keep children that are `Avatar` component
   */
  const avatarChildren = React.Children.toArray(children).filter(element => /*#__PURE__*/isValidElement(element) && element.type === Avatar);
  const truncatedChildren = max != null ? avatarChildren.slice(0, max) : avatarChildren;
  const excess = max != null ? avatarChildren.length - max : 0;
  const reversedChildren = truncatedChildren.reverse();
  const clones = reversedChildren.map((child, index) => {
    const isFirstAvatar = index === 0;
    const childProps = {
      ml: isFirstAvatar ? 0 : '-lg',
      borderWidth: 3,
      borderColor,
      borderRadius,
      size: child?.props.size ? child.props.size : props.size
    };
    return /*#__PURE__*/cloneElement(child, compact(childProps));
  });
  const groupStyles = {
    display: 'flex',
    alignItems: 'center',
    justifyContent: 'flex-start',
    flexDirection: 'row-reverse',
    spacing: '0',
    ...styles.group
  };
  const excessStyles = {
    borderRadius,
    ml: '-lg',
    ...styles.excessLabel
  };
  return /*#__PURE__*/_jsxs(HStack, {
    ref: ref,
    role: "group",
    __styles: groupStyles,
    ...rest,
    children: [clones, excess > 0 && /*#__PURE__*/_jsx(Avatar, {
      __styles: excessStyles,
      name: `+${excess}`,
      colorScheme: "gray",
      getInitials: excessValue => excessValue
    })]
  });
});
//# sourceMappingURL=avatar-group.js.map