"use strict";

import { useMemo } from 'react';
import React from 'react';
import { omitThemingProps, splitTextProps } from "../../style-system/index.js";
import { ficus, forwardRef, useMultiStyleConfig } from "../system/index.js";
import { AvatarImage } from "./avatar-image.js";
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
export const Avatar = forwardRef(function Avatar(props, ref) {
  const styles = useMultiStyleConfig('Avatar', props);
  const {
    borderRadius = 'full',
    src,
    name,
    getInitials,
    children,
    __styles,
    ...rest
  } = omitThemingProps(props);
  const [textStyles, restProps] = splitTextProps(rest);
  const avatarContainerStyles = useMemo(() => ({
    borderRadius,
    alignItems: 'center',
    justifyContent: 'center',
    ...styles.container,
    ...__styles // Useful for avatar excess label
  }), [styles.container]);
  const labelStyles = useMemo(() => ({
    ...styles.label,
    ...textStyles
  }), [styles.label, textStyles]);
  return /*#__PURE__*/_jsxs(ficus.View, {
    ref: ref,
    ...restProps,
    __styles: avatarContainerStyles,
    children: [/*#__PURE__*/_jsx(AvatarImage, {
      src: src,
      name: name,
      borderRadius: borderRadius,
      getInitials: getInitials,
      labelStyles: labelStyles
    }), React.Children.map(children, child => {
      return /*#__PURE__*/React.cloneElement(child, {
        __styles: {
          ...styles.badge,
          ...child.props.__styles
        },
        size: props.size ?? styles.container?.width
      });
    })]
  });
});
//# sourceMappingURL=avatar.js.map