"use strict";

import { cleanup, fireEvent, screen } from '@testing-library/react-native';
import { ActivityIndicator, View } from 'react-native';
import { Button } from "./index.js";
import { renderWithTheme as render } from "../../test-utils/index.js";
import { theme } from "../../theme/index.js";
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
afterEach(cleanup);
describe('Button component', () => {
  it('should render without errors', () => {
    const {
      getByText
    } = render(/*#__PURE__*/_jsx(Button, {
      children: "I love Ficus UI (forked from Magnus UI)"
    }));
    expect(getByText('I love Ficus UI (forked from Magnus UI)')).toBeTruthy();
  });
  it('should pressing trigger event', () => {
    const onPressMock = jest.fn();
    const {
      getByText
    } = render(/*#__PURE__*/_jsx(Button, {
      onPress: onPressMock,
      children: "Click Me"
    }));
    const button = getByText('Click Me');
    fireEvent.press(button);
    expect(onPressMock).toHaveBeenCalledTimes(1);
  });
  it('should be disabled when isDisabled is true', () => {
    const onPressMock = jest.fn();
    const {
      getByText
    } = render(/*#__PURE__*/_jsx(Button, {
      onPress: onPressMock,
      isDisabled: true,
      children: "Click Me"
    }));
    expect(onPressMock).not.toHaveBeenCalled();
    const button = getByText('Click Me');
    fireEvent.press(button);
    expect(onPressMock).not.toHaveBeenCalled();
  });
  it('should render ActivityIndicator component if loading', () => {
    render(/*#__PURE__*/_jsx(Button, {
      isLoading: true
    }));
    const activityIndicator = screen.UNSAFE_getByType(ActivityIndicator);
    expect(activityIndicator).toBeTruthy();
  });
  it('should have background color of bg prop value', () => {
    const colorNameButtonId = 'colorNameButton';
    const hexCodeButtonId = 'hexCodeButton';
    const specificHueButtonId = 'specificHueButton';
    const red = 'red';
    const hexCode = '#FED7D7';
    const red600 = 'red.600';
    const {
      getByTestId
    } = render(/*#__PURE__*/_jsxs(View, {
      children: [/*#__PURE__*/_jsx(Button, {
        testID: colorNameButtonId,
        bg: red
      }), /*#__PURE__*/_jsx(Button, {
        testID: hexCodeButtonId,
        bg: hexCode
      }), /*#__PURE__*/_jsx(Button, {
        testID: specificHueButtonId,
        bg: red600
      })]
    }));
    const specificHueButton = getByTestId(specificHueButtonId);
    expect(specificHueButton.props.style).toHaveProperty('backgroundColor');
    expect(specificHueButton.props.style.backgroundColor).toEqual(theme?.colors?.red?.[600]);
  });
  it('should render text with color', () => {
    const buttonId = 'button';
    const {
      getByText
    } = render(/*#__PURE__*/_jsx(Button, {
      testID: buttonId,
      color: "black",
      children: "This is the button"
    }));
    const text = getByText('This is the button');
    expect(text.props.style).toHaveProperty('color');
    expect(text.props.style.color).toEqual('#000000');
  });
});
//# sourceMappingURL=button.spec.js.map