"use strict";

import { omit } from '@chakra-ui/utils';
import { omitThemingProps } from "../../style-system/index.js";
import { Pressable } from "../pressable/index.js";
import { ficus, forwardRef, useStyleConfig } from "../system/index.js";
import { ButtonSpinner } from "./button-spinner.js";
import { useButton } from "./button.service.js";
import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
export const Button = forwardRef(function Button(props, ref) {
  const styles = useStyleConfig('Button', props);
  const {
    getChildren,
    buttonStyles,
    spinnerStyles,
    loadingText
  } = useButton(props, styles);
  const {
    isLoading,
    isDisabled,
    ...rest
  } = omitThemingProps(omit(props, ['children']));
  return /*#__PURE__*/_jsxs(Pressable, {
    ref: ref,
    disabled: isDisabled || isLoading,
    "aria-disabled": isDisabled || isLoading,
    rounded: props.isRound ? 'full' : undefined,
    __styles: buttonStyles,
    ...rest,
    children: [isLoading && /*#__PURE__*/_jsx(ButtonSpinner, {
      ...spinnerStyles
    }), isLoading ? loadingText || /*#__PURE__*/_jsx(ficus.View, {
      opacity: 0,
      children: getChildren()
    }) : /*#__PURE__*/_jsx(_Fragment, {
      children: getChildren()
    })]
  });
});
//# sourceMappingURL=index.js.map