"use strict";

import { cloneElement, isValidElement, useEffect, useState } from 'react';
import { isFunction } from '@chakra-ui/utils';
import { omitThemingProps } from "../../style-system/index.js";
import { Icon } from "../icon/index.js";
import { ficus, forwardRef, useMultiStyleConfig } from "../system/index.js";
import { useCheckbox } from "./checkbox.service.js";
import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
export const Checkbox = forwardRef(({
  icon = /*#__PURE__*/_jsx(Icon, {
    name: "checkmark-outline"
  }),
  ...props
}, ref) => {
  const styles = useMultiStyleConfig('Checkbox', props);
  const {
    isDisabled,
    isChecked,
    defaultChecked,
    onChange,
    onPress,
    children,
    value,
    bg,
    __styles,
    ...rest
  } = omitThemingProps(props);
  const [checked, setChecked] = useState(('isChecked' in props ? isChecked : defaultChecked) ?? false);
  const {
    containerStyles,
    controlStyles,
    labelStyles,
    iconStyles
  } = useCheckbox({
    ...props,
    isChecked: checked
  }, styles);
  useEffect(() => {
    if ('isChecked' in props) {
      setChecked(props.isChecked ?? false);
    }
  }, [props]);

  /**
   * on press checkbox
   */
  const handleOnPress = event => {
    if (isDisabled) {
      return;
    }
    setChecked(!checked);
    if (isFunction(onChange)) {
      onChange(value);
    }
    if (isFunction(onPress)) {
      onPress(event);
    }
  };
  const enhancedIcon = /*#__PURE__*/isValidElement(icon) ? /*#__PURE__*/cloneElement(icon, {
    ...(iconStyles.name ? {
      name: iconStyles.name
    } : {}),
    ...(iconStyles.color ? {
      color: iconStyles.color
    } : {}),
    ...(iconStyles.size ? {
      size: iconStyles.size
    } : {}),
    ...(iconStyles.iconSet ? {
      iconSet: iconStyles.iconSet
    } : {}),
    __styles: iconStyles
  }) : icon;
  const renderChildren = () => {
    if (isFunction(children)) {
      return children({
        isDisabled: isDisabled ?? false,
        isChecked: checked
      });
    }
    return /*#__PURE__*/_jsxs(_Fragment, {
      children: [/*#__PURE__*/_jsx(ficus.View, {
        __styles: controlStyles,
        children: enhancedIcon
      }), children && typeof children === 'string' ? /*#__PURE__*/_jsx(ficus.Text, {
        __styles: labelStyles,
        children: children
      }) : children]
    });
  };
  return /*#__PURE__*/_jsx(ficus.TouchableOpacity, {
    ref: ref,
    onPress: handleOnPress,
    disabled: isDisabled,
    activeOpacity: 0.5,
    __styles: containerStyles,
    ...rest,
    children: renderChildren()
  });
});
//# sourceMappingURL=index.js.map