"use strict";

import { useMemo } from 'react';
import { useColorMode } from "../../hooks/index.js";
import { ficus, forwardRef } from "../system/index.js";
import { jsx as _jsx } from "react/jsx-runtime";
/**
 * Layout component used to visually separate content in a list or group.
 * It displays a thin horizontal or vertical line
 */
export const Divider = forwardRef(function Divider(props, ref) {
  const {
    colorMode
  } = useColorMode();
  const {
    orientation = 'horizontal',
    color = colorMode === 'dark' ? 'white' : 'black',
    __styles,
    ...rest
  } = props;
  const dividerStyles = useMemo(() => {
    const bg = color;
    return {
      vertical: {
        w: 1,
        h: '100%',
        bg
      },
      horizontal: {
        h: 1,
        w: '100%',
        bg
      }
    };
  }, [color]);
  return /*#__PURE__*/_jsx(ficus.View, {
    ref: ref,
    ...rest,
    __styles: {
      ...dividerStyles[orientation],
      ...__styles
    }
  });
});
//# sourceMappingURL=index.js.map