"use strict";

import { useEffect, useRef } from 'react';
import { SafeAreaView } from 'react-native';
import { useColorMode } from "../../hooks/index.js";
import { useTheme } from "../../theme/index.js";
import { Box } from "../box/index.js";
import { ficus, forwardRef, toStyleSheetObject } from "../system/index.js";
import { mergeRefs } from "../utils/merge-refs.js";
import { jsx as _jsx } from "react/jsx-runtime";
export const DraggableModal = forwardRef(function DraggableModal(props, ref) {
  const _ref = useRef(null);
  const {
    theme
  } = useTheme();
  const {
    colorMode
  } = useColorMode();
  const bottomSheetModalRef = mergeRefs(_ref, ref);
  const {
    children,
    isOpen,
    onClose,
    h,
    ...rest
  } = props;
  useEffect(() => {
    if (isOpen) {
      _ref?.current?.present();
      _ref?.current?.snapToIndex(0);
    } else {
      _ref?.current?.close();
    }
  }, [isOpen]);
  const bottomSheetStyles = {
    h: 'full',
    justifyContent: 'flex-end',
    borderTopLeftRadius: 12,
    borderTopRightRadius: 12
  };
  const bottomSheetBackgroundStyles = {
    backgroundColor: colorMode === 'dark' ? 'gray.900' : 'white'
  };
  const bottomSheetBackgroundStyleObject = toStyleSheetObject({
    baseStyle: bottomSheetBackgroundStyles
  })({
    ...bottomSheetBackgroundStyles,
    theme,
    style: undefined
  });
  const handleStyles = {
    backgroundColor: colorMode === 'dark' ? 'white' : 'gray.600'
  };
  const handleStyleObject = toStyleSheetObject({
    baseStyle: handleStyles
  })({
    ...handleStyles,
    theme,
    style: undefined
  });
  const handleChange = index => {
    if (index === -1 && onClose) {
      onClose();
    }
  };
  const safeAreaViewStyle = {
    flex: 1
  };
  return /*#__PURE__*/_jsx(ficus.BottomSheetModal, {
    ref: bottomSheetModalRef,
    onChange: handleChange,
    ...rest,
    __styles: bottomSheetStyles,
    backgroundStyle: bottomSheetBackgroundStyleObject,
    handleIndicatorStyle: handleStyleObject,
    children: /*#__PURE__*/_jsx(ficus.BottomSheetView, {
      ...rest,
      children: /*#__PURE__*/_jsx(Box, {
        h: h ?? '100%',
        children: /*#__PURE__*/_jsx(SafeAreaView, {
          style: safeAreaViewStyle,
          children: children
        })
      })
    })
  });
});
//# sourceMappingURL=index.js.map