"use strict";

import { fireEvent } from '@testing-library/react-native';
import { IconButton } from "./index.js";
import { renderWithTheme as render } from "../../test-utils/index.js";
import { Icon } from "../icon/index.js";
import { getIconSet } from "../icon/icon.service.js";
import { jsx as _jsx } from "react/jsx-runtime";
jest.mock('../icon/icon.service', () => ({
  getIconSet: jest.fn(() => jest.fn(() => null)) // Mock the icon component
}));
describe('IconButton component', () => {
  it('should render default icon with no props', () => {
    const {
      getByTestId
    } = render(/*#__PURE__*/_jsx(IconButton, {
      testID: "icon-button-no-props",
      icon: /*#__PURE__*/_jsx(Icon, {
        name: "home"
      })
    }));
    expect(getIconSet).toHaveBeenCalled();
    expect(getByTestId('icon-button-no-props')).toBeTruthy();
  });
  it('should pressing trigger event', () => {
    const onPressMock = jest.fn();
    const {
      getByTestId
    } = render(/*#__PURE__*/_jsx(IconButton, {
      testID: "icon-button-press",
      icon: /*#__PURE__*/_jsx(Icon, {
        name: "home"
      }),
      onPress: onPressMock
    }));
    const button = getByTestId('icon-button-press');
    fireEvent.press(button);
    expect(onPressMock).toHaveBeenCalledTimes(1);
  });
});
//# sourceMappingURL=icon-button.spec.js.map