"use strict";

import { cloneElement, isValidElement } from 'react';
import { omit } from '@chakra-ui/utils';
import { omitThemingProps } from "../../style-system/index.js";
import { ButtonSpinner } from "../button/button-spinner.js";
import { useButton } from "../button/button.service.js";
import { Pressable } from "../pressable/index.js";
import { forwardRef, useStyleConfig } from "../system/index.js";
import { jsx as _jsx } from "react/jsx-runtime";
export const IconButton = forwardRef(function IconButton(props, ref) {
  const styles = useStyleConfig('IconButton', props);
  const {
    textStyles,
    buttonStyles,
    spinnerStyles
  } = useButton(props, styles);
  const {
    isLoading,
    isDisabled,
    ...rest
  } = omitThemingProps(omit(props, ['children']));
  const enhancedIcon = /*#__PURE__*/isValidElement(props.icon) ? /*#__PURE__*/cloneElement(props.icon, {
    color: textStyles?.color,
    size: textStyles?.fontSize
  }) : props.icon;
  return /*#__PURE__*/_jsx(Pressable, {
    ref: ref,
    disabled: isDisabled || isLoading,
    "aria-disabled": isDisabled || isLoading,
    rounded: props.isRound ? 'full' : undefined,
    __styles: buttonStyles,
    ...rest,
    children: isLoading ? /*#__PURE__*/_jsx(ButtonSpinner, {
      ...spinnerStyles
    }) : enhancedIcon
  });
});
//# sourceMappingURL=index.js.map