"use strict";

import { useImperativeHandle, useRef, useState } from 'react';
import { splitProps } from '@chakra-ui/utils';
import { useColorModeValue } from "../../hooks/index.js";
import { isStyleProp, omitThemingProps } from "../../style-system/index.js";
import { useTheme } from "../../theme/index.js";
import { ButtonSpinner } from "../button/button-spinner.js";
import { ficus, forwardRef, useStyleConfig } from "../system/index.js";
import { useInput } from "./input.service.js";
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
export const Input = forwardRef((props, ref) => {
  const [isFocused, setIsFocused] = useState(false);
  const innerRef = useRef(null);
  const {
    theme
  } = useTheme();
  useImperativeHandle(ref, () => innerRef.current);
  const [stylesProps, inputProps] = splitProps(props, isStyleProp);
  const styles = useStyleConfig('Input', {
    ...stylesProps,
    size: inputProps?.size,
    variant: inputProps?.variant
  });
  const {
    inputStyles,
    spinnerStyles,
    inputContainerStyles,
    prefixStyles,
    suffixStyles
  } = useInput(props, styles, isFocused);
  const propsWithoutThemingProps = omitThemingProps(inputProps);
  const {
    onFocus,
    onBlur,
    prefix,
    suffix,
    isLoading,
    isDisabled,
    ...rest
  } = propsWithoutThemingProps;

  /**
   * on focus input
   *
   * @param e
   */
  const onFocusInput = e => {
    setIsFocused(true);
    if (onFocus) {
      onFocus(e);
    }
  };

  /**
   * on blur input
   *
   * @param e
   */
  const onBlurInput = e => {
    setIsFocused(false);
    if (onBlur) {
      onBlur(e);
    }
  };
  const onPressComponent = () => {
    if (innerRef?.current) {
      innerRef?.current?.focus();
    }
  };
  const colorValue = useColorModeValue(500, 300);
  return /*#__PURE__*/_jsx(ficus.TouchableWithoutFeedback, {
    onPress: onPressComponent,
    children: /*#__PURE__*/_jsxs(ficus.View, {
      __styles: inputContainerStyles,
      ...(isFocused && props.colorScheme ? {
        borderColor: `${props.colorScheme}.${colorValue}`
      } : {}),
      children: [prefix && /*#__PURE__*/_jsx(ficus.View, {
        __styles: prefixStyles,
        children: prefix
      }), /*#__PURE__*/_jsx(ficus.TextInput, {
        ref: innerRef,
        onFocus: onFocusInput,
        onBlur: onBlurInput,
        __styles: inputStyles,
        editable: !isDisabled,
        "aria-disabled": isDisabled,
        placeholderTextColor: theme?.colors?.gray?.[500],
        ...rest
      }), !isLoading && suffix && /*#__PURE__*/_jsx(ficus.View, {
        __styles: suffixStyles,
        children: suffix
      }), isLoading && /*#__PURE__*/_jsx(ficus.View, {
        __styles: suffixStyles,
        children: /*#__PURE__*/_jsx(ButtonSpinner, {
          ...spinnerStyles
        })
      })]
    })
  });
});
export { Textarea } from "./textarea.js";
//# sourceMappingURL=index.js.map