"use strict";

import { useImperativeHandle, useRef, useState } from 'react';
import { splitProps } from '@chakra-ui/utils';
import { isStyleProp, omitThemingProps } from "../../style-system/index.js";
import { ButtonSpinner } from "../button/button-spinner.js";
import { ficus, forwardRef, useStyleConfig } from "../system/index.js";
import { useInput } from "./input.service.js";
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
export const Textarea = forwardRef((props, ref) => {
  const [isFocused, setIsFocused] = useState(false);
  const innerRef = useRef(null);
  useImperativeHandle(ref, () => innerRef.current);
  const [stylesProps, inputProps] = splitProps(props, isStyleProp);
  const styles = useStyleConfig('Textarea', stylesProps);
  const {
    inputStyles,
    inputContainerStyles,
    prefixStyles,
    suffixStyles,
    spinnerStyles
  } = useInput(props, styles, isFocused);
  const propsWithoutThemingProps = omitThemingProps(inputProps);
  const {
    onFocus,
    onBlur,
    prefix,
    suffix,
    isLoading,
    isDisabled,
    ...rest
  } = propsWithoutThemingProps;

  /**
   * on focus input
   *
   * @param e
   */
  const onFocusInput = e => {
    setIsFocused(true);
    if (onFocus) {
      onFocus(e);
    }
  };

  /**
   * on blur input
   *
   * @param e
   */
  const onBlurInput = e => {
    setIsFocused(false);
    if (onBlur) {
      onBlur(e);
    }
  };
  const onPressComponent = () => {
    if (innerRef?.current) {
      innerRef?.current?.focus();
    }
  };
  return /*#__PURE__*/_jsx(ficus.TouchableWithoutFeedback, {
    onPress: onPressComponent,
    children: /*#__PURE__*/_jsx(ficus.View, {
      children: /*#__PURE__*/_jsxs(ficus.View, {
        __styles: inputContainerStyles,
        children: [prefix && /*#__PURE__*/_jsx(ficus.View, {
          __styles: prefixStyles,
          children: prefix
        }), /*#__PURE__*/_jsx(ficus.TextInput, {
          ref: innerRef,
          onFocus: onFocusInput,
          onBlur: onBlurInput,
          __styles: inputStyles,
          editable: !isDisabled,
          "aria-disabled": !isDisabled,
          multiline: true,
          ...rest
        }), !isLoading && suffix && /*#__PURE__*/_jsx(ficus.View, {
          __styles: suffixStyles,
          children: suffix
        }), isLoading && /*#__PURE__*/_jsx(ficus.View, {
          __styles: suffixStyles,
          children: /*#__PURE__*/_jsx(ButtonSpinner, {
            ...spinnerStyles
          })
        })]
      })
    })
  });
});
//# sourceMappingURL=textarea.js.map