"use strict";

import { List } from "./index.js";
import { renderWithTheme as render } from "../../test-utils/index.js";
import { Text } from "../text/index.js";
import { jsx as _jsx } from "react/jsx-runtime";
jest.mock('react-native-toast-message', () => 'Toast');
describe('List component', () => {
  const mockData = [{
    id: '1',
    title: 'First Item'
  }, {
    id: '2',
    title: 'Second Item'
  }, {
    id: '3',
    title: 'Third Item'
  }];
  it('should render without crashing', () => {
    const {
      getByTestId
    } = render(/*#__PURE__*/_jsx(List, {
      testID: "list-container",
      data: mockData,
      renderItem: ({
        item
      }) => /*#__PURE__*/_jsx(Text, {
        children: item?.title
      })
    }));
    expect(getByTestId('list-container')).toBeTruthy();
  });
  it('should render the correct number of list items', () => {
    const {
      getAllByTestId
    } = render(/*#__PURE__*/_jsx(List, {
      data: mockData,
      renderItem: ({
        item
      }) => /*#__PURE__*/_jsx(Text, {
        testID: "list-item",
        children: item.title
      })
    }));
    const items = getAllByTestId('list-item');
    expect(items.length).toBe(mockData.length);
  });
  it('should display correct item text', () => {
    const {
      getByText
    } = render(/*#__PURE__*/_jsx(List, {
      data: mockData,
      renderItem: ({
        item
      }) => /*#__PURE__*/_jsx(Text, {
        children: item.title
      })
    }));
    expect(getByText('First Item')).toBeTruthy();
    expect(getByText('Second Item')).toBeTruthy();
    expect(getByText('Third Item')).toBeTruthy();
  });
  it('should use the correct keyExtractor', () => {
    const keyExtractor = jest.fn(item => item.id);
    render(/*#__PURE__*/_jsx(List, {
      data: mockData,
      renderItem: ({
        item
      }) => /*#__PURE__*/_jsx(Text, {
        children: item.title
      }),
      keyExtractor: keyExtractor
    }));
    expect(keyExtractor).toHaveBeenCalledWith(mockData[0], 0);
    expect(keyExtractor).toHaveBeenCalledWith(mockData[1], 1);
    expect(keyExtractor).toHaveBeenCalledWith(mockData[2], 2);
  });
  it('should render empty list when no data is passed', () => {
    const {
      queryAllByTestId
    } = render(/*#__PURE__*/_jsx(List, {
      data: [],
      renderItem: ({
        item
      }) => /*#__PURE__*/_jsx(Text, {
        testID: "list-item",
        children: item.title
      })
    }));
    expect(queryAllByTestId('list-item').length).toBe(0);
  });
});
//# sourceMappingURL=list.spec.js.map