"use strict";

import React from 'react';
import { splitProps } from '@chakra-ui/utils';
import { isStyleProp, omitThemingProps } from "../../style-system/index.js";
import { useTheme } from "../../theme/index.js";
import { ficus, forwardRef, toStyleSheetObject, useStyleConfig } from "../system/index.js";
import { PinInputField } from "./pin-input-field.js";
import { usePinInput } from "./pin-input.service.js";
import { jsx as _jsx } from "react/jsx-runtime";
export const PinInput = forwardRef((props, ref) => {
  const [stylesProps, inputProps] = splitProps(props, isStyleProp);
  const {
    theme
  } = useTheme();
  const styles = useStyleConfig('PinInput', stylesProps);
  const {
    pinInputStyles
  } = usePinInput(props, styles);
  const propsWithoutThemingProps = omitThemingProps(inputProps);
  const {
    mask,
    placeholder,
    children,
    cellCount,
    ...rest
  } = propsWithoutThemingProps;
  const pinInputFields = React.Children.toArray(children).filter(child => child.type?.displayName === 'PinInputField');
  const styleObject = toStyleSheetObject({
    baseStyle: pinInputStyles
  })({
    ...pinInputStyles,
    theme
  });
  const renderCell = ({
    index,
    symbol,
    isFocused
  }) => /*#__PURE__*/_jsx(PinInputField, {
    index: index,
    symbol: symbol,
    mask: mask,
    placeholder: placeholder,
    isFocused: isFocused,
    ...inputProps
  }, `pin-input-field-${index}`);
  return /*#__PURE__*/_jsx(ficus.CodeField, {
    ref: ref,
    renderCell: renderCell,
    rootStyle: styleObject,
    cellCount: pinInputFields?.length > 0 ? pinInputFields?.length : cellCount,
    ...rest
  });
});
//# sourceMappingURL=index.js.map