"use strict";

import { splitProps } from '@chakra-ui/utils';
import { Cursor, MaskSymbol, isLastFilledCell } from 'react-native-confirmation-code-field';
import { useColorModeValue } from "../../hooks/index.js";
import { isStyleProp, omitThemingProps } from "../../style-system/index.js";
import { ficus, forwardRef, useStyleConfig } from "../system/index.js";
import { Text } from "../text/index.js";
import { usePinInputField } from "./pin-input.service.js";
import { jsx as _jsx } from "react/jsx-runtime";
export const PinInputField = forwardRef((props, ref) => {
  const [stylesProps, inputProps] = splitProps(props, isStyleProp);
  const styles = useStyleConfig('PinInputField', {
    ...stylesProps,
    size: inputProps?.size,
    variant: inputProps?.variant
  });
  const {
    pinInputFieldStyles
  } = usePinInputField(props, styles);
  const propsWithoutThemingProps = omitThemingProps(inputProps);
  const {
    mask,
    placeholder,
    symbol,
    value,
    index,
    isFocused,
    ...rest
  } = propsWithoutThemingProps;
  let textChild = null;
  if (symbol && mask) {
    textChild = /*#__PURE__*/_jsx(MaskSymbol, {
      maskSymbol: placeholder || '•',
      isLastFilledCell: isLastFilledCell({
        index: index || 0,
        value: value || ''
      }),
      children: symbol
    });
  } else if (symbol && !mask) {
    textChild = /*#__PURE__*/_jsx(Text, {
      children: symbol
    });
  } else if (isFocused) {
    textChild = /*#__PURE__*/_jsx(Text, {
      children: /*#__PURE__*/_jsx(Cursor, {})
    });
  } else {
    textChild = '';
  }
  const colorValue = useColorModeValue(500, 300);
  return /*#__PURE__*/_jsx(ficus.View, {
    ref: ref,
    children: /*#__PURE__*/_jsx(ficus.View, {
      __styles: pinInputFieldStyles,
      ...(isFocused && props.colorScheme ? {
        borderColor: `${props.colorScheme}.${colorValue}`
      } : {}),
      ...rest,
      children: /*#__PURE__*/_jsx(ficus.Text, {
        color: "black",
        fontWeight: "bold",
        children: textChild
      })
    })
  }, index);
});
PinInputField.displayName = 'PinInputField';
//# sourceMappingURL=pin-input-field.js.map