"use strict";

import { useMemo } from 'react';
import { useColorMode } from "../../hooks/index.js";
import { getStateStyles } from "../system/get-state-styles.js";
/**
 * Custom hook for managing pin input behavior and styles.
 */
export function usePinInput(props, styles) {
  const {
    isDisabled
  } = props;
  const {
    colorMode
  } = useColorMode();

  // Compute styles based on state
  const stateStyles = useMemo(() => getStateStyles({
    disabled: isDisabled
  }, styles, colorMode), [isDisabled, styles, colorMode]);
  const pinInputStyles = useMemo(() => ({
    ...stateStyles
  }), [stateStyles]);
  return {
    pinInputStyles
  };
}

/**
 * Custom hook for managing pin input field behavior and styles.
 */
export function usePinInputField(props, styles) {
  const {
    isDisabled,
    isFocused
  } = props;
  const {
    colorMode
  } = useColorMode();

  // Compute styles based on state
  const stateStyles = useMemo(() => getStateStyles({
    disabled: isDisabled,
    focused: isFocused
  }, styles, colorMode), [isDisabled, isFocused, styles, colorMode]);
  const pinInputFieldStyles = useMemo(() => ({
    ...stateStyles
  }), [stateStyles]);
  return {
    pinInputFieldStyles
  };
}
//# sourceMappingURL=pin-input.service.js.map