"use strict";

import { Pressable } from "./index.js";
import { renderWithTheme as render } from "../../test-utils/index.js";
import { theme } from "../../theme/index.js";
import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
describe('Pressable component', () => {
  it('should render correctly with default props', () => {
    const {
      getByTestId
    } = render(/*#__PURE__*/_jsx(Pressable, {
      testID: "pressable-default"
    }));
    expect(getByTestId('pressable-default')).toBeTruthy();
  });
  it('should apply custom styles', () => {
    const {
      getByTestId
    } = render(/*#__PURE__*/_jsx(Pressable, {
      testID: "pressable-styled",
      bg: "red.500"
    }));
    expect(getByTestId('pressable-styled')).toHaveStyle({
      backgroundColor: theme.colors.red[500]
    });
  });
  it('should apply _pressed styles when pressed', () => {
    const {
      getByTestId
    } = render(/*#__PURE__*/_jsxs(_Fragment, {
      children: [/*#__PURE__*/_jsx(Pressable, {
        testOnly_pressed: true,
        testID: "pressable-pressed",
        bg: "blue.600",
        _pressed: {
          bg: 'blue.500'
        }
      }), /*#__PURE__*/_jsx(Pressable, {
        testOnly_pressed: false,
        testID: "pressable-not-pressed",
        bg: "blue.600",
        _pressed: {
          bg: 'blue.500'
        }
      })]
    }));
    const pressablePressed = getByTestId('pressable-pressed');
    expect(pressablePressed).toHaveStyle({
      backgroundColor: theme.colors.blue[500]
    });
    const pressableNotPressed = getByTestId('pressable-not-pressed');
    expect(pressableNotPressed).toHaveStyle({
      backgroundColor: theme.colors.blue[600]
    });
  });
});
//# sourceMappingURL=pressable.spec.js.map