"use strict";

import React, { useState } from 'react';
import { Radio } from "./index.js";
import { omitThemingProps } from "../../style-system/index.js";
import { ficus, forwardRef, useMultiStyleConfig } from "../system/index.js";
import { jsx as _jsx } from "react/jsx-runtime";
export const RadioGroup = forwardRef((props, ref) => {
  const styles = useMultiStyleConfig('RadioGroup', props);
  const {
    isDisabled,
    onChange,
    children,
    ...rest
  } = omitThemingProps(props);
  const [value, setValue] = useState(props.value ?? props.defaultValue ?? []);

  /**
   * checks if checked value is already in the state or not,
   * if it, remove it else add it
   *
   * @param value
   */
  const handleOnChange = optionValue => {
    if (!('value' in props)) {
      setValue(optionValue);
    }
    if (onChange) {
      onChange(optionValue);
    }
  };

  /**
   * clones the children and add checked, onChange prop
   */
  const renderChildren = () => {
    const renderRecursive = childrenProp => {
      // @ts-expect-error : conversion issue
      return React.Children.map(childrenProp, child => {
        if (! /*#__PURE__*/React.isValidElement(child)) return child;

        // If child is a Radio component
        if (child.type === Radio) {
          return /*#__PURE__*/React.cloneElement(child, {
            key: `radio-${child.props.value}`,
            // @ts-expect-error : conversion issue
            onChange: handleOnChange,
            isChecked: value === child.props.value,
            ...(props.colorScheme ? {
              colorScheme: props.colorScheme
            } : {})
          });
        }

        // If child has children, apply recursively
        if (child.props?.children) {
          const updatedChildren = renderRecursive(child.props.children);
          return /*#__PURE__*/React.cloneElement(child, undefined, updatedChildren);
        }
        return child;
      });
    };
    return children ? renderRecursive(children) : null;
  };
  return /*#__PURE__*/_jsx(ficus.View, {
    ref: ref,
    __styles: styles,
    ...rest,
    children: renderChildren()
  });
});
//# sourceMappingURL=radio-group.js.map