"use strict";

import { useMemo } from 'react';
import { useColorMode } from "../../hooks/index.js";
import { getStateStyles } from "../system/get-state-styles.js";

/**
 * Custom hook for managing radio behavior and styles.
 */
export function useRadio(props, styles) {
  const {
    isDisabled,
    isChecked
  } = props;
  const {
    colorMode
  } = useColorMode();
  const containerStyles = useMemo(() => getStateStyles({
    disabled: isDisabled,
    checked: isChecked
  }, styles.container || {}, colorMode), [isDisabled, isChecked, colorMode]);
  const controlStyles = useMemo(() => getStateStyles({
    disabled: isDisabled,
    checked: isChecked
  }, styles.control || {}, colorMode), [isDisabled, isChecked, colorMode]);
  const labelStyles = useMemo(() => getStateStyles({
    disabled: isDisabled,
    checked: isChecked
  }, styles.label || {}, colorMode), [isDisabled, isChecked, colorMode]);
  return {
    containerStyles,
    controlStyles,
    labelStyles
  };
}
//# sourceMappingURL=radio.service.js.map