"use strict";

import { SectionList } from "./index.js";
import { renderWithTheme as render } from "../../test-utils/index.js";
import { Box } from "../box/index.js";
import { Text } from "../text/index.js";
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
const MySectionList = ({
  sections
}) => {
  return /*#__PURE__*/_jsx(SectionList, {
    sections: sections,
    keyExtractor: (item, index) => (item.title + index).toString(),
    renderItem: ({
      item
    }) => /*#__PURE__*/_jsxs(Box, {
      p: "sm",
      children: [/*#__PURE__*/_jsx(Text, {
        children: item.title
      }), " "]
    }),
    renderSectionHeader: ({
      section: {
        title
      }
    }) => /*#__PURE__*/_jsx(Box, {
      bg: "gray.300",
      p: "sm",
      children: /*#__PURE__*/_jsx(Text, {
        children: title
      })
    })
  });
};
describe('MySectionList component', () => {
  const sections = [{
    title: 'Section 1',
    data: [{
      id: '1',
      title: 'Item 1'
    }, {
      id: '2',
      title: 'Item 2'
    }]
  }, {
    title: 'Section 2',
    data: [{
      id: '3',
      title: 'Item 3'
    }, {
      id: '4',
      title: 'Item 4'
    }]
  }];
  it('renders section headers and items correctly', () => {
    const {
      getByText
    } = render(/*#__PURE__*/_jsx(MySectionList, {
      sections: sections
    }));

    // Check if section headers are rendered
    expect(getByText('Section 1')).toBeTruthy();
    expect(getByText('Section 2')).toBeTruthy();

    // Check if items are rendered
    expect(getByText('Item 1')).toBeTruthy();
    expect(getByText('Item 2')).toBeTruthy();
    expect(getByText('Item 3')).toBeTruthy();
    expect(getByText('Item 4')).toBeTruthy();
  });
});
//# sourceMappingURL=section-list.spec.js.map