"use strict";

import React, { useState } from 'react';
import { useColorModeValue } from "../../hooks/index.js";
import { useTheme } from "../../theme/index.js";
import { ficus, forwardRef, toStyleSheetObject, useStyleConfig } from "../system/index.js";
import { useSelect } from "./select.service.js";
import { jsx as _jsx } from "react/jsx-runtime";
export const Select = forwardRef((props, ref) => {
  const styles = useStyleConfig('Select', props);
  const [isFocused, setIsFocused] = useState(false);
  const {
    theme
  } = useTheme();
  const {
    selectStyles
  } = useSelect(styles, isFocused);
  const colorValue = useColorModeValue(500, 300);
  const inputStyle = toStyleSheetObject({
    baseStyle: selectStyles
  })({
    ...selectStyles,
    theme,
    style: undefined,
    ...(isFocused && props.colorScheme ? {
      borderColor: `${props.colorScheme}.${colorValue}`
    } : {})
  });
  return /*#__PURE__*/_jsx(ficus.PickerSelect, {
    ref: ref,
    placeholder: {
      label: 'Select an option...',
      value: undefined
    },
    style: {
      inputIOSContainer: {
        pointerEvents: 'none'
      },
      inputIOS: inputStyle,
      inputAndroid: inputStyle
    },
    onOpen: () => setIsFocused(true),
    onClose: () => setIsFocused(false)
    // To make is focused work on android
    ,
    pickerProps: {
      onFocus: () => setIsFocused(true),
      onBlur: () => setIsFocused(false)
    },
    useNativeAndroidPickerStyle: false,
    ...props
  });
});
//# sourceMappingURL=index.js.map