"use strict";

import { useMemo } from 'react';
import { useColorMode } from "../../hooks/index.js";
import { getStateStyles } from "../system/get-state-styles.js";

/**
 * Custom hook for managing select behavior and styles.
 */
export function useSelect(styles, isFocused) {
  const {
    colorMode
  } = useColorMode();

  // Compute styles based on state
  const stateStyles = useMemo(() => getStateStyles({
    focused: isFocused
  }, styles, colorMode), [isFocused, styles, colorMode]);
  const selectStyles = useMemo(() => ({
    ...stateStyles
  }), [stateStyles]);
  return {
    selectStyles
  };
}
//# sourceMappingURL=select.service.js.map