"use strict";

import { useMemo } from 'react';
import { getColor, useTheme } from "../../theme/index.js";
import { ficus, forwardRef, useMultiStyleConfig } from "../system/index.js";
import { jsx as _jsx } from "react/jsx-runtime";
export const Slider = forwardRef(function Slider(props, ref) {
  const styles = useMultiStyleConfig('Slider', props);
  const {
    theme
  } = useTheme();
  const {
    min,
    max,
    defaultValue,
    trackColor,
    filledTrackColor,
    thumbColor,
    ...rest
  } = props;
  const sliderColors = useMemo(() => ({
    minimumTrackTintColor: getColor(trackColor ?? styles.track?.bg, theme.colors),
    maximumTrackTintColor: getColor(filledTrackColor ?? styles.filledTrack?.bg, theme.colors),
    thumbTintColor: getColor(thumbColor ?? styles.thumb?.bg, theme.colors)
  }), [trackColor, filledTrackColor, thumbColor, styles]);
  return /*#__PURE__*/_jsx(ficus.Slider, {
    ref: ref,
    minimumValue: min,
    maximumValue: max,
    value: defaultValue,
    ...sliderColors,
    ...rest
  });
});
//# sourceMappingURL=index.js.map