"use strict";

import { Fragment, cloneElement, useMemo } from 'react';
import { getValidChildren } from '@chakra-ui/utils';
import { ficus, forwardRef } from "../system/index.js";
import { getDividerStyles } from "./stack.utils.js";
import { jsxs as _jsxs, jsx as _jsx } from "react/jsx-runtime";
/**
 * Stacks help you easily create flexible and automatically distributed layouts
 *
 * You can stack elements in the horizontal or vertical direction,
 * and apply a space or/and divider between each element.
 *
 */
export const Stack = forwardRef((props, ref) => {
  const {
    direction: flexDirection,
    children,
    divider,
    spacing,
    ...rest
  } = props;
  const direction = flexDirection ?? 'column';
  const dividerStyle = useMemo(() => getDividerStyles({
    spacing,
    direction
  }), [spacing, direction]);
  const hasDivider = !!divider;
  const shouldUseChildren = !hasDivider;
  const clones = useMemo(() => {
    const validChildren = getValidChildren(children);
    return shouldUseChildren ? validChildren : validChildren.map((child, index) => {
      const key = typeof child.key !== 'undefined' ? child.key : index;
      const isLast = index + 1 === validChildren.length;
      const _child = child;
      if (!hasDivider) return _child;
      const clonedDivider = /*#__PURE__*/cloneElement(divider, {
        __style: dividerStyle
      });
      const _divider = isLast ? null : clonedDivider;
      return /*#__PURE__*/_jsxs(Fragment, {
        children: [_child, _divider]
      }, key);
    });
  }, [divider, dividerStyle, hasDivider, shouldUseChildren, children]);
  return /*#__PURE__*/_jsx(ficus.View, {
    ref: ref,
    display: "flex",
    gap: hasDivider ? undefined : spacing,
    ...rest,
    children: clones
  });
});
//# sourceMappingURL=stack.js.map