"use strict";

import { useEffect, useRef, useState } from 'react';
import { Animated } from 'react-native';
import { omitThemingProps } from "../../style-system/index.js";
import { getColor, useTheme } from "../../theme/index.js";
import { ficus, forwardRef, toStyleSheetObject, useMultiStyleConfig } from "../system/index.js";
import { useSwitch } from "./switch.service.js";
import { jsx as _jsx } from "react/jsx-runtime";
export const Switch = forwardRef((props, ref) => {
  const {
    theme
  } = useTheme();
  const styles = useMultiStyleConfig('Switch', props);
  const {
    isDisabled,
    isChecked,
    duration,
    onPress,
    bg,
    __styles,
    ...rest
  } = omitThemingProps(props);
  const prevSwitchOnRef = useRef();
  const prevSwitchOn = !!prevSwitchOnRef.current;
  const {
    containerStyles,
    trackStyles,
    thumbStyles
  } = useSwitch(props, styles);
  const trackStyleObject = toStyleSheetObject({
    baseStyle: trackStyles
  })({
    ...trackStyles,
    style: {},
    theme
  });
  const thumbStyleObject = toStyleSheetObject({
    baseStyle: thumbStyles
  })({
    ...thumbStyles,
    style: {},
    theme
  });
  const [animXValue] = useState(new Animated.Value(isChecked ? 1 : 0));
  const endPos = (trackStyleObject.width || 0) - thumbStyleObject.width - (trackStyleObject.padding * 2 || 0);
  const circlePosXEnd = endPos;
  const [circlePosXStart] = useState(0);

  /**
   *
   */
  useEffect(() => {
    const runAnimation = () => {
      const animValue = {
        fromValue: isChecked ? 0 : 1,
        toValue: isChecked ? 1 : 0,
        duration: duration || theme.components?.Switch?.defaultProps?.duration,
        useNativeDriver: false
      };
      Animated.timing(animXValue, animValue).start();
    };
    prevSwitchOnRef.current = isChecked;
    if (prevSwitchOn !== isChecked) {
      runAnimation();
    }
  }, [animXValue, prevSwitchOn, isChecked, duration]);
  return /*#__PURE__*/_jsx(ficus.TouchableOpacity, {
    ref: ref,
    onPress: !isDisabled ? onPress : () => {},
    disabled: isDisabled,
    activeOpacity: 0.5,
    __styles: containerStyles,
    w: trackStyleObject.width,
    ...rest,
    children: /*#__PURE__*/_jsx(Animated.View, {
      style: [trackStyleObject, {
        backgroundColor: animXValue.interpolate({
          inputRange: [0, 1],
          outputRange: [getColor(styles.track?.bg, theme.colors), getColor(trackStyles?.bg, theme.colors)]
        })
      }],
      children: /*#__PURE__*/_jsx(Animated.View, {
        style: [thumbStyleObject, {
          backgroundColor: animXValue.interpolate({
            inputRange: [0, 1],
            outputRange: [getColor(styles.thumb?.bg, theme.colors), getColor(thumbStyles?.bg, theme.colors)]
          })
        }, {
          transform: [{
            translateX: animXValue.interpolate({
              inputRange: [0, 1],
              outputRange: [circlePosXStart, circlePosXEnd]
            })
          }]
        }]
      })
    })
  });
});
//# sourceMappingURL=index.js.map