"use strict";

import { useMemo } from 'react';
import { useColorMode } from "../../hooks/index.js";
import { getStateStyles } from "../system/get-state-styles.js";

/**
 * Custom hook for managing switch behavior and styles.
 */
export function useSwitch(props, styles) {
  const {
    isDisabled,
    isChecked
  } = props;
  const {
    colorMode
  } = useColorMode();
  const containerStyles = useMemo(() => getStateStyles({
    disabled: isDisabled,
    checked: isChecked
  }, styles.container || {}, colorMode), [isDisabled, isChecked, colorMode]);
  const trackStyles = useMemo(() => getStateStyles({
    disabled: isDisabled,
    checked: isChecked
  }, styles.track || {}, colorMode), [isDisabled, isChecked, colorMode]);
  const thumbStyles = useMemo(() => getStateStyles({
    disabled: isDisabled,
    checked: isChecked
  }, styles.thumb || {}, colorMode), [isDisabled, isChecked, colorMode]);
  return {
    containerStyles,
    trackStyles,
    thumbStyles
  };
}
//# sourceMappingURL=switch.service.js.map