"use strict";

import { createElement, forwardRef } from 'react';
import { assignAfter, compact, runIfFn, splitProps } from '@chakra-ui/utils';
import { useColorMode } from "../../hooks/index.js";
import { isStyleProp, styleSheet } from "../../style-system/index.js";
import { useTheme } from "../../theme/index.js";
import { getComponent } from "./system.utils.js";
export const toStyleSheetObject = ({
  baseStyle
}) => props => {
  const {
    theme,
    style,
    __styles,
    ...styleProps
  } = props;
  const finalBaseStyle = runIfFn(baseStyle, props);
  const finalStyles = assignAfter({}, __styles, finalBaseStyle, compact(styleProps), style);
  return styleSheet(finalStyles)(theme);
};
export function styled(component, options) {
  const {
    baseStyle,
    excludedProps = [],
    styleProp = 'style'
  } = options ?? {};
  const styleObject = toStyleSheetObject({
    baseStyle
  });
  const Component = getComponent(component);
  const ficusComponent = /*#__PURE__*/forwardRef(function FicusComponent(props, ref) {
    const {
      children,
      style,
      as,
      __styles,
      __stylesFn,
      ...rest
    } = props;
    const {
      theme
    } = useTheme();
    const {
      colorMode
    } = useColorMode();
    const restResult = colorMode === 'dark' ? {
      ...rest,
      ...rest._dark
    } : rest;
    const isExcludedProp = prop => excludedProps.includes(prop);
    const [styleProps, restProps] = splitProps(restResult, prop => isStyleProp(prop) && !isExcludedProp(prop));
    const AsComponent = as ? getComponent(as) : Component;
    const propsWithTheme = {
      style,
      theme,
      __styles,
      ...styleProps
    };
    const computedStyle = styleObject(propsWithTheme);
    const finalComputedStyle = __stylesFn ? __stylesFn(computedStyle, colorMode) : computedStyle;
    return /*#__PURE__*/createElement(AsComponent, {
      ref,
      [styleProp]: finalComputedStyle,
      ...restProps
    }, children);
  });
  return ficusComponent;
}
//# sourceMappingURL=system.js.map