"use strict";

import { useRef } from 'react';
import { compact, memoizedGet as get, mergeWith, omit } from '@chakra-ui/utils';
import isEqual from 'react-fast-compare';
import { useColorMode } from "../../hooks/index.js";
import { resolveStyleConfig } from "../../style-system/index.js";
import { useTheme } from "../../theme/index.js";
function useStyleConfigFn(themeKey, props = {}) {
  const {
    styleConfig: styleConfigProp,
    ...rest
  } = props;
  const {
    theme
  } = useTheme();
  const {
    colorMode
  } = useColorMode();
  const themeStyleConfig = themeKey ? get(theme, `components.${themeKey}`) : undefined;
  const styleConfig = styleConfigProp || themeStyleConfig;
  const mergedProps = mergeWith({
    theme,
    colorMode
  }, styleConfig?.defaultProps ?? {}, compact(omit(rest, ['children'])), (obj, src) => !obj ? src : undefined);

  /**
   * Store the computed styles in a `ref` to avoid unneeded re-computation
   */
  const stylesRef = useRef({});
  if (styleConfig) {
    const getStyles = resolveStyleConfig(styleConfig);
    const styles = getStyles(mergedProps);
    const isStyleEqual = isEqual(stylesRef.current, styles);
    if (!isStyleEqual) {
      stylesRef.current = styles;
    }
  }
  return stylesRef.current;
}

/**
 * Allow to resolve style config from the theme and merge it with props passed by the user.
 */
export function useStyleConfig(themeKey, props = {}) {
  return useStyleConfigFn(themeKey, props);
}

/**
 * Allow to resolve style config for multi parts component
 */
export function useMultiStyleConfig(themeKey, props = {}) {
  return useStyleConfigFn(themeKey, props);
}
//# sourceMappingURL=use-style-config.js.map