"use strict";

import React, { useState } from 'react';
import { splitProps } from '@chakra-ui/utils';
import { Dimensions } from 'react-native';
import { SceneMap, TabBar } from 'react-native-tab-view';
import { useColorMode } from "../../hooks/index.js";
import { isStyleProp } from "../../style-system/index.js";
import { useTheme } from "../../theme/index.js";
import { ficus, toStyleSheetObject, useStyleConfig } from "../system/index.js";
import { Text } from "../text/index.js";

// [FIXME]: There is probably a way to abstract the style handling more generally.
import { jsx as _jsx } from "react/jsx-runtime";
export const Tabs = props => {
  const {
    children,
    selectedTab,
    onChangeTab,
    initialPage,
    colorScheme = 'blue',
    ...rest
  } = props;
  const {
    theme
  } = useTheme();
  const {
    colorMode
  } = useColorMode();
  const [stylesProps, tabsProps] = splitProps(props, isStyleProp);
  const styles = useStyleConfig('Tabs', {
    ...stylesProps,
    variant: tabsProps?.variant
  });
  const [index, setIndex] = useState(initialPage || 0);
  const tabs = React.Children.toArray(children).find(child => child.type === TabList);
  const panels = React.Children.toArray(children).find(child => child.type === TabPanels);
  const routes = React.Children.map(tabs?.props.children, child => ({
    key: child.props.name,
    title: child.props.name,
    renderLabelChildren: child.props.children,
    otherProps: child.props
  }));
  const tabSceneMap = panels?.props.children.reduce((scenes, child) => {
    const {
      linkedTo,
      children: panelChildren,
      ...panelRest
    } = child.props;
    scenes[linkedTo] = () => /*#__PURE__*/_jsx(TabPanel, {
      ...panelRest,
      children: panelChildren
    });
    return scenes;
  }, {});
  const tabsMainColor = colorScheme ? colorMode === 'dark' ? `${colorScheme}.200` : `${colorScheme}.600` : null;
  const tabListStyles = useStyleConfig('TabList', {
    ...tabs.props,
    variant: tabsProps?.variant
  });
  const tabListStyleObject = toStyleSheetObject({
    baseStyle: tabListStyles
  })({
    ...tabListStyles,
    ...(tabsMainColor ? {
      indicatorStyle: {
        backgroundColor: tabsMainColor
      }
    } : {}),
    theme,
    style: undefined
  });

  // Construct the scene map from TabPanel children
  const renderScene = SceneMap(tabSceneMap);
  const renderLabel = ({
    route,
    focused,
    color
  }) => {
    if (typeof route.renderLabelChildren === 'string') {
      return /*#__PURE__*/_jsx(Text, {
        color: tabsMainColor || color,
        children: route.renderLabelChildren
      });
    }
    return /*#__PURE__*/_jsx(ficus.View, {
      children: typeof route.renderLabelChildren === 'function' ? route.renderLabelChildren({
        route,
        focused,
        color
      }) : route.renderLabelChildren
    });
  };
  return /*#__PURE__*/_jsx(ficus.TabView, {
    ...rest,
    navigationState: {
      index: selectedTab !== undefined ? selectedTab : index,
      routes
    },
    initialLayout: {
      width: Dimensions.get('screen').width
    },
    renderScene: renderScene,
    onIndexChange: ind => {
      onChangeTab(ind);
      setIndex(ind);
    },
    renderTabBar: sceneProps => {
      return /*#__PURE__*/_jsx(TabBar, {
        renderLabel: renderLabel,
        style: tabListStyleObject,
        ...(tabListStyleObject?.indicatorStyle ? {
          indicatorStyle: tabListStyleObject?.indicatorStyle
        } : {}),
        ...tabs?.props,
        ...sceneProps,
        ...rest
      });
    },
    __styles: styles
  });
};
export const Tab = props => /*#__PURE__*/_jsx(ficus.View, {
  ...props
});
export const TabList = props => /*#__PURE__*/_jsx(ficus.View, {
  ...props
});
export const TabPanel = props => /*#__PURE__*/_jsx(ficus.View, {
  ...props
});
export const TabPanels = ficus('View');
//# sourceMappingURL=index.js.map