"use strict";

import { screen } from '@testing-library/react-native';
import { Text } from "./index.js";
import { renderWithTheme as render } from "../../test-utils/index.js";
import { theme } from "../../theme/index.js";
import { jsx as _jsx } from "react/jsx-runtime";
jest.mock('react-native-toast-message', () => 'Toast');
describe('Text component', () => {
  it('should render text correctly', () => {
    render(/*#__PURE__*/_jsx(Text, {
      children: "I love Ficus UI (forked from Magnus UI)"
    }));
    expect(screen.getByText('I love Ficus UI (forked from Magnus UI)')).toBeTruthy();
  });
  it('should apply styles correctly', () => {
    const {
      getByText
    } = render(/*#__PURE__*/_jsx(Text, {
      fontSize: "xl",
      color: "blue.500",
      children: "Styled Text"
    }));
    const textElement = getByText('Styled Text');
    expect(textElement).toBeTruthy();
    expect(textElement).toHaveStyle({
      color: theme.colors.blue[500],
      fontSize: theme.fontSizes.xl
    });
  });
  it('should support theming props', () => {
    render(/*#__PURE__*/_jsx(Text, {
      fontWeight: "bold",
      children: "Themed Text"
    }));
    const textElement = screen.getByText('Themed Text');
    expect(textElement).toBeTruthy();
    expect(textElement).toHaveStyle({
      fontWeight: 700
    });
  });
});
//# sourceMappingURL=text.spec.js.map