"use strict";

import { isValidColor } from "../../theme/utilities/index.js";
// NOTE: This function are taken from Magnus and could probably be improved
export const transforms = {
  getThemeProp(value, themeScope) {
    if (themeScope?.[value]) {
      return themeScope[value];
    }
    return value;
  },
  getFontWeight(value, themeScope) {
    const fontFamilyKey = value.fontFamily ?? '';
    const fontFamily = themeScope.fontFamily?.[fontFamilyKey];
    if (fontFamily) {
      return 'normal';
    }
    const resolvedFontWeight = resolveFontWeight(value.fontWeight, themeScope);
    return resolvedFontWeight;
  },
  getThemeFontFamily(value, themeScope) {
    const rawFontWeight = value.fontWeight;
    const rawFontFamily = value.fontFamily;
    const fontFamily = themeScope.fontFamily?.[rawFontFamily] ?? {};
    const resolvedFontWeight = resolveFontWeight(rawFontWeight, themeScope);
    return fontFamily[resolvedFontWeight] ?? rawFontFamily;
  },
  getThemeColor(value, theme) {
    let colorValueResult = value;
    if (theme && value) {
      // Check if color value is a valid theme color
      if (theme.hasOwnProperty(value) && (typeof theme[value] === 'string' || theme[value] instanceof String)) {
        const colorValue = theme[value];
        return colorValue;
      }

      // If color value contains dots, check into theme sub objects if it's a valid theme color
      if (value.includes('.')) {
        const keyParts = value.split('.');
        let subPropertyValue = theme;
        for (const part of keyParts) {
          if (subPropertyValue && part) {
            subPropertyValue = subPropertyValue[part];
          }
        }
        if (typeof subPropertyValue === 'string' || subPropertyValue instanceof String) {
          colorValueResult = subPropertyValue;
        }
      }
    }
    return isValidColor(colorValueResult) ? colorValueResult : 'transparent';
  }
};
const resolveFontWeight = (fontWeight = 'normal', themeScope) => {
  return (
    // If font weight is a keyword (`light  `, `normal`, ...) map it to a number (300, 400)
    themeScope.fontWeights[fontWeight] ??
    // If font weight is already number (300, 400)
    fontWeight
  );
};
//# sourceMappingURL=transform-functions.js.map