"use strict";

import { useEffect, useMemo, useState } from 'react';
import deepmerge from 'deepmerge';
import { useWindowDimensions } from 'react-native';
import Toast from 'react-native-toast-message';
import { ThemeContext } from "./context.js";
import { theme } from "./theme.default.js";
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
export const ThemeProvider = props => {
  const {
    theme: customTheme = {},
    children
  } = props;

  // Get Metadata
  const {
    width: windowWidth
  } = useWindowDimensions();
  const breakpoints = theme?.breakpoints ? Object.entries(theme.breakpoints).sort((a, b) => a[1] - b[1]) : [];

  // Add metadata to the theme
  const themeWithMetadata = Object.assign(theme, {
    __windowWidth: windowWidth,
    __breakpoints: breakpoints
  });
  const [themeState, setThemeState] = useState(deepmerge(themeWithMetadata, customTheme));
  const [colorMode, setColorMode] = useState('light');
  const setTheme = newTheme => {
    const mergedTheme = deepmerge(themeState, newTheme);
    setThemeState(mergedTheme);
  };
  const contextValue = useMemo(() => ({
    theme: themeState,
    setTheme,
    colorMode,
    setColorMode
  }), [themeState, colorMode]);
  useEffect(() => {
    setTheme({
      __windowWidth: windowWidth
    });
  }, [windowWidth]);
  return /*#__PURE__*/_jsxs(ThemeContext.Provider, {
    value: contextValue,
    children: [children, /*#__PURE__*/_jsx(Toast, {
      ...themeState.toastProps
    })]
  });
};
//# sourceMappingURL=provider.js.map