import { FlexStyle, ImageStyle, TextStyle, ViewStyle } from 'react-native';
import { ThemeScope } from '../theme.types';
import { Transform } from './types';
export type RNStyleSheet = TextStyle & ViewStyle & FlexStyle & ImageStyle;
export type RNStyleSheetProperties = keyof RNStyleSheet;
type MaybeArray<T> = T | T[];
export interface PropConfig {
    /**
     * The theme scope this maps to
     */
    scope?: ThemeScope;
    /**
     * StyleSheet or React Native prop
     * This can be undefined in case the property maps to a theme aware style that includes several properties.
     * E.g. `shadow` prop which maps to the theme scope `shadows`
     */
    property?: MaybeArray<RNStyleSheetProperties | (string & {})>;
    /**
     * Function to transform the value passed
     */
    transform?: Transform;
    /**
     * Array of properties that may be needed to transform the current prop
     * e.g. fontWeight needs fontFamily
     */
    peerProperties?: string[];
}
export type Config<T = string> = Record<T extends Record<string, any> ? keyof T : string, PropConfig | true>;
export declare function toConfig(scope: ThemeScope, transform?: Transform): <T extends "transform" | "color" | "fontFamily" | "fontSize" | "fontStyle" | "fontWeight" | "letterSpacing" | "lineHeight" | "textAlign" | "textDecorationLine" | "textDecorationStyle" | "textDecorationColor" | "textShadowColor" | "textShadowOffset" | "textShadowRadius" | "textTransform" | "userSelect" | "fontVariant" | "writingDirection" | "backfaceVisibility" | "backgroundColor" | "borderBlockColor" | "borderBlockEndColor" | "borderBlockStartColor" | "borderBottomColor" | "borderBottomEndRadius" | "borderBottomLeftRadius" | "borderBottomRightRadius" | "borderBottomStartRadius" | "borderColor" | "borderCurve" | "borderEndColor" | "borderEndEndRadius" | "borderEndStartRadius" | "borderLeftColor" | "borderRadius" | "borderRightColor" | "borderStartColor" | "borderStartEndRadius" | "borderStartStartRadius" | "borderStyle" | "borderTopColor" | "borderTopEndRadius" | "borderTopLeftRadius" | "borderTopRightRadius" | "borderTopStartRadius" | "opacity" | "elevation" | "pointerEvents" | "isolation" | "cursor" | "boxShadow" | "filter" | "alignContent" | "alignItems" | "alignSelf" | "aspectRatio" | "borderBottomWidth" | "borderEndWidth" | "borderLeftWidth" | "borderRightWidth" | "borderStartWidth" | "borderTopWidth" | "borderWidth" | "bottom" | "display" | "end" | "flex" | "flexBasis" | "flexDirection" | "rowGap" | "gap" | "columnGap" | "flexGrow" | "flexShrink" | "flexWrap" | "height" | "justifyContent" | "left" | "margin" | "marginBottom" | "marginEnd" | "marginHorizontal" | "marginLeft" | "marginRight" | "marginStart" | "marginTop" | "marginVertical" | "maxHeight" | "maxWidth" | "minHeight" | "minWidth" | "overflow" | "padding" | "paddingBottom" | "paddingEnd" | "paddingHorizontal" | "paddingLeft" | "paddingRight" | "paddingStart" | "paddingTop" | "paddingVertical" | "position" | "right" | "start" | "top" | "width" | "zIndex" | "direction" | "inset" | "insetBlock" | "insetBlockEnd" | "insetBlockStart" | "insetInline" | "insetInlineEnd" | "insetInlineStart" | "marginBlock" | "marginBlockEnd" | "marginBlockStart" | "marginInline" | "marginInlineEnd" | "marginInlineStart" | "paddingBlock" | "paddingBlockEnd" | "paddingBlockStart" | "paddingInline" | "paddingInlineEnd" | "paddingInlineStart" | "shadowColor" | "shadowOffset" | "shadowOpacity" | "shadowRadius" | "transformOrigin" | "transformMatrix" | "rotation" | "scaleX" | "scaleY" | "translateX" | "translateY" | "textAlignVertical" | "verticalAlign" | "includeFontPadding" | "resizeMode" | "overlayColor" | "tintColor" | "objectFit">(property?: T | T[] | undefined) => PropConfig;
export {};
//# sourceMappingURL=prop-config.d.ts.map